import React, { useState, useEffect } from 'react'
import { Input, Modal } from 'antd'
import { Editor, Toolbar } from '@wangeditor/editor-for-react'
import styles from './index.less'
import Drag from '../../../../components/Drag'

const { TextArea } = Input

const uploadFileAPI = `/PandaWorkFlow/WorkFlow/AccountManage/UploaderFiles`;
const downFileAPI = `/PandaWorkFlow/WorkFlow/AccountManage/DownloadFiles`;

const ContentHTML = (props) => {

  const { value, onChange, schema } = props
  const [visible, setVisible] = useState(false)
  const [editor, setEditor] = useState(null)

  const inputClick = () => {
    setVisible(true)
  }

  // const editorChange = (editor) => {
  //   onChange(editor.getHtml())
  // }

  const onOk = () => {
    onChange(editor.getHtml())
    setVisible(false)
  }

  useEffect(() => {
    return () => {
      if (editor == null) return
      editor.destroy()
      setEditor(null)
    }
  }, [editor])

  useEffect(() => {
    if (!visible && editor) {
      editor.destroy()
      setEditor(null)
    }
  }, [visible])

  return (
    <div>
      <TextArea value={value} onClick={() => inputClick()} />
      <Drag
        title={'控件内容'}
        visible={visible}
        width={1100}
        bodyStyle={{ height: '500px', overflowY: 'auto' }}
        onCancel={() => setVisible(false)}
        onOk={onOk}
      >
        <div className={styles.richText}>
          <Toolbar
            editor={editor}
            defaultConfig={{
              excludeKeys: ['insertLink', 'group-image', 'group-video', 'codeBlock', 'undo', 'redo', 'fullScreen']
            }}
            mode="default"
            style={{ borderBottom: '1px solid #ccc' }}
          />
          <Editor
            defaultConfig={{
              readOnly: false,
              placeholder: '请输入内容',
              focus: false,
              pasteFilterStyle: true, // 忽略粘贴样式
              pasteIgnoreImg: true, // 忽略粘贴的图片
              styleWithCSS: false,
              zIndex: 500,
              MENU_CONF: {
                uploadImage: {
                  customInsert(res, inserFn) {
                    const formData = new FormData();
                    formData.append('file', file);
                  },
                  server: uploadFileAPI,
                }
              }
            }}
            value={value}
            onCreated={value => {
              if (!editor) {
                setEditor(value)
              }
            }}
            // onChange={editorChange}
            mode="default"
            style={{ minHeight: '400px', overflowY: 'hidden' }}
          />
        </div>
      </Drag>
    </div>
  )

}

export default ContentHTML